==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/photos/PHCachingImageManager.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.photos;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.avfoundation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 8.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("Photos") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/PHCachingImageManager/*</name>*/ 
    extends /*<extends>*/PHImageManager/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class PHCachingImageManagerPtr extends Ptr<PHCachingImageManager, PHCachingImageManagerPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(PHCachingImageManager.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public PHCachingImageManager() {}
    protected PHCachingImageManager(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "allowsCachingHighQualityImages")
    public native boolean allowsCachingHighQualityImages();
    @Property(selector = "setAllowsCachingHighQualityImages:")
    public native void setAllowsCachingHighQualityImages(boolean v);
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "startCachingImagesForAssets:targetSize:contentMode:options:")
    public native void startCachingImagesForAssets(NSArray<PHAsset> assets, @ByVal CGSize targetSize, PHImageContentMode contentMode, PHImageRequestOptions options);
    @Method(selector = "stopCachingImagesForAssets:targetSize:contentMode:options:")
    public native void stopCachingImagesForAssets(NSArray<PHAsset> assets, @ByVal CGSize targetSize, PHImageContentMode contentMode, PHImageRequestOptions options);
    @Method(selector = "stopCachingImagesForAllAssets")
    public native void stopCachingImagesForAllAssets();
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/photos/PHCachingImageManager.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.photos;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.avfoundation.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.imageio.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("Photos") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/PHCachingImageManager/*</name>*/ 
    extends /*<extends>*/PHImageManager/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class PHCachingImageManagerPtr extends Ptr<PHCachingImageManager, PHCachingImageManagerPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(PHCachingImageManager.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public PHCachingImageManager() {}
    protected PHCachingImageManager(Handle h, long handle) { super(h, handle); }
    protected PHCachingImageManager(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "allowsCachingHighQualityImages")
    public native boolean allowsCachingHighQualityImages();
    @Property(selector = "setAllowsCachingHighQualityImages:")
    public native void setAllowsCachingHighQualityImages(boolean v);
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "startCachingImagesForAssets:targetSize:contentMode:options:")
    public native void startCachingImagesForAssets(NSArray<PHAsset> assets, @ByVal CGSize targetSize, PHImageContentMode contentMode, PHImageRequestOptions options);
    @Method(selector = "stopCachingImagesForAssets:targetSize:contentMode:options:")
    public native void stopCachingImagesForAssets(NSArray<PHAsset> assets, @ByVal CGSize targetSize, PHImageContentMode contentMode, PHImageRequestOptions options);
    @Method(selector = "stopCachingImagesForAllAssets")
    public native void stopCachingImagesForAllAssets();
    @Method(selector = "defaultManager")
    public static native PHImageManager getDefaultManager();
    /*</methods>*/
}
